#
# spec file for package php5-pear-DB
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           php5-pear-DB
%define pear_name  DB
%define pear_sname db
Summary:        Database Abstraction Layer
License:        PHP-3.01
Group:          Productivity/Networking/Web/Servers
Version:        1.8.2
Release:        6.1
BuildArch:      noarch
Url:            http://pear.php.net/package/%{pear_name}
Source:         http://download.pear.php.net/package/DB-%{version}.tgz
Source1:        %{pear_name}.rpmlintrc

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  php >= 5.0.0
%if 0%{?sles_version} == 10
BuildRequires:  php-macros
%else
BuildRequires:  php-devel >= 5.0.0
%endif
BuildRequires:  php-pear >= 1.4.0
Requires:       php >= 5.0.0
Requires:       php-pear >= 1.4.0

Provides:       pear-%{pear_name}
Provides:       pear-%{pear_sname} = %{version}
Provides:       php-pear-%{pear_name}
Provides:       php-pear-%{pear_sname} = %{version}
Provides:       php5-pear-%{pear_sname} = %{version}
Obsoletes:      pear-%{pear_sname} < %{version}
Obsoletes:      php-pear-%{pear_sname} < %{version}
Obsoletes:      php5-pear-%{pear_sname} < %{version}

%description
DB is a database abstraction layer providing:
* an OO-style query API
* portability features that make programs written for one DBMS work with other DBMS's
* a DSN (data source name) format for specifying database servers
* prepare/execute (bind) emulation for databases that don't support it natively
* a result object for each query response
* portable error codes
* sequence emulation
* sequential and non-sequential row fetching as well as bulk fetching
* formats fetched rows as associative arrays, ordered arrays or objects
* row limit support
* transactions support
* table information interface
* DocBook and phpDocumentor API documentation

DB layers itself on top of PHP's existing database extensions.

Drivers for the following extensions pass the complete test suite and provide
interchangeability when all of DB's portability options are enabled:

  fbsql, ibase, informix, msql, mssql,
  mysql, mysqli, oci8, odbc, pgsql,
  sqlite and sybase.

There is also a driver for the dbase extension, but it can't be used
interchangeably because dbase doesn't support many standard DBMS features.

%prep
%setup -c

%build

%install
%{__mv} package*.xml %{pear_name}-%{version}
cd %{pear_name}-%{version}
PHP_PEAR_PHP_BIN="$(which php) -d memory_limit=50m"
%{__pear} -v \
        -d doc_dir=/doc \
        -d bin_dir=%{_bindir} \
        -d data_dir=%{php_peardir}/data \
        install --offline --nodeps -R "%{buildroot}" package.xml

%{__install} -D -m 0644 package.xml %{buildroot}%{php_pearxmldir}/%{pear_name}.xml

%{__rm} -rf %{buildroot}/{doc,tmp}
%{__rm} -rf "%{buildroot}"/%{php_peardir}/.{filemap,lock,registry,channels,depdb,depdblock}

# fix for brp-check-buildroot
%{__sed} -i -e "s@%{buildroot}@@g" %{buildroot}%{php_peardir}/test/%{pear_name}/tests/driver/setup.inc
%{__sed} -i -e "s@%{buildroot}@@g" %{buildroot}%{php_peardir}/test/%{pear_name}/tests/include.inc
cd ..

%php_pear_gen_filelist

%post
# on `rpm -ivh` PARAM is 1
# on `rpm -Uvh` PARAM is 2
if [ "$1" = "1" ]; then
  %{__pear} install --nodeps --soft --force --register-only %{php_pearxmldir}/%{pear_name}.xml
fi
if [ "$1" = "2" ]; then
  %{__pear} upgrade --offline --register-only %{php_pearxmldir}/%{pear_name}.xml
fi

%postun
# on `rpm -e` PARAM is 0
if [ "$1" = "0" ]; then
  %{__pear} uninstall --nodeps --ignore-errors --register-only pear.php.net/%{pear_name}
fi

%clean
%{__rm} -rf %{buildroot}

%files -f %{name}.files
%defattr(-, root, root)
%doc %{pear_name}-%{version}/doc/*

%changelog
* Thu Dec 11 2014 aj@ajaissle.de
- New release to 1.8.2
  * Fix bug #20447 (Have quoteString() remove quotes like it used to)
- Release 1.8.1
  * Fix bug #19785 (Ensure calling quote() is safe)
- Release 1.8.0
  * E_STRICT compliance, require PHP 5.
  * Fix array to string conversion in connect() when class does not exist.
* Thu Mar 14 2013 pgajdos@suse.com
- remove whole %%check section
  http://lists.opensuse.org/opensuse-factory/2013-03/msg00420.html
* Thu Mar 14 2013 pgajdos@suse.com
- really run tests
* Fri Feb  1 2013 aj@ajaissle.de
- Improved spec to serve more build targets.
* Tue Nov 27 2012 Ralf Lang <lang@b1-systems.de>
- version 1.7.14
- All drivers:
  Made the definition of DB_common::raiseError() compatible with PEAR::raiseError() by adding dummy parameters. Request 11581.
  Fixed SKIP block in the 20locale.phpt test.
  Fixed non-persistent connections to really be non-persistent when unserialising. Bug 15115.
- pgsql:
  Added special-case to handle SAVEPOINT queries as manip queries. Bug 12260.
  Implement rudimentary support for WITH...SELECT queries. Bug 17136.
- sqlite:
  Added support for another error message in the SQLite driver. Bug 12105, patch by Adam Ashley.
  Implement auto_increment support in tableInfo(). Request 13193.
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Thu Jan 20 2011 chris@computersalat.de
- change to php_pear_gen_filelist macro
* Wed Jan 19 2011 chris@computersalat.de
- pkg rename php5-pear-DBL
- merge with php-pear-DB, php5-pear-db
- changelog to changes file
- added php-macros
- added rpmlintrc file
* Sat May 30 2009 chris@computersalat.de
- fixed post script
* Thu May 21 2009 chris@computersalat.de
- added stuff to automatically create correct filelist
  o tested against Factory (1120)
  o opensuse >= 1100 complains about
    "directory not owned by package"
- some rpmlint stuff
  o added rpmlintrc
- bzip2 Source
* Tue May 19 2009 chris@computersalat.de
- beautify spec
  o new spec header
  o package rename due to package convention
  o removed php4 stuff, deps
  o added Provides and Obsoletes for old package names.
    This should not break deps
* Sun Jun 15 2008 lars@linux-schulserver.de
- update to 1.7.13:
  + Replaced instances of '=& new Foo' with '= new Foo' to make
    DB (slightly) more E_STRICT friendly.
  + Added an explicit call to select the database to fix calls
    to tableInfo() without a preceding query.
  + Altered fetchInto() to remove extraneous quotes returned
    by SQLite.
- Prov/Obs php-pear-db
- disable old specfile
- removed DB-1.7.6-dependency.patch
- run pear tests during build
- cleanup specfile a bit
* Wed Jul 25 2007 mmarek@suse.cz
- updated to 1.7.12
  * fixes an issue that prevented PostgreSQL users from escaping
    values with PHP 5.2
* Sat Jun 23 2007 judas_iscariote@shorewall.net
- update to pear-db 1.7.11 [#278175]
- adapt package to new pear package format
